# IMPORTANT NOTE: 1.SUPPORT FOR PACKAGEIMPORTER <=1.3.0 HAS OFFICIALLY DROPPED. WE WILL NO LONGER BE SEEING ANYMORE BUGFIXES IN FUTURE VERSION (IF ANY) ABOUT BUGFIXES APPEARING IN THIS VERSION; 2.PLEASE DOWNLOAD THIS NEW VERSION, NOT PACKAGEIMPORTER 1.4.0 FOR THE NEWEST BUGFIXES

# About

## PackageImporter is a simple project for importing projects according to different types (DataScience, Plotting, etc.). It can also be used to install packages and inspect installed packages.

# Installation

## To install PackageImporter, run this command into your terminal (Use Windows Powershell because I love it):

### `pip install packageimporter`

## For a specific version, run:

### `pip install packageimporter=={version}`

## To upgrade the exsisting PackageImporter module (which you probably don't):

### `pip install --upgrade packageimporter`

## note: you can either use `python -m pip` or `py -m pip` if it's different (HINT: It may). PackageImporter has only one limitation: `Python>=3.8`

# Usage Example

## `from packageimporter import Importer`

## `Importer.stable.Plotter.plotly.express(alias="i_love_plotly_express")`

### # This will import plotly.express as i_love_plotly_express (weird alias) and raise an ModuleNotFoundError if plotly.express is not globally installed.

# Update Notes:

## Minor Bugfixes on error while class calling

## Updates on README.MD

## PICDT (PackageImporter CoreDev Team joined with Fasthelp Dev Team (FDT))

### PS: Guess we'll have to wait for PIIP (PackageImporter Insider Project) in packageimporter v1.5.0...

(↑Y)

# Thanks to all, JVSCode Dev Team (JDT)
